'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const fs = require('fs');
const path = require('path');
const utils = require('./utils.cjs');

function _interopNamespace(e) {
    if (e && e.__esModule) return e;
    const n = Object.create(null);
    if (e) {
        for (const k in e) {
            n[k] = e[k];
        }
    }
    n["default"] = e;
    return n;
}

const fs__namespace = /*#__PURE__*/_interopNamespace(fs);

function matchPath(node, target, level, path) {
  if (!node) {
    return {
      level,
      path
    };
  }
  if (node.type === "ArrayExpression") {
    let isMatch = false;
    let index = void 0;
    let childrenIndex = void 0;
    node.elements.forEach((n, i) => {
      let flag = false;
      n.properties.forEach((item, itemIndex) => {
        let regexp = new RegExp(`^/?${target[level]}(:.*)?$`);
        if (item.key.name === "path" && regexp.test(item.value.value)) {
          isMatch = true;
          flag = true;
          index = i;
        }
        if (flag && item.key.name === "children") {
          childrenIndex = itemIndex;
        }
      });
    });
    if (isMatch) {
      path += `${level > 0 ? `['value']` : ""}['elements'][${index}]['properties']${typeof childrenIndex === "number" ? `[${childrenIndex}]` : ""}`;
    } else if (level === 0) {
      path += "['elements']";
    }
    if (isMatch && typeof index === "number") {
      let n = typeof childrenIndex === "number" ? node.elements[index].properties[childrenIndex].value : null;
      return matchPath(n, target, level + 1, path);
    }
  }
  return {
    level,
    path
  };
}
function writeRouterAst(ast, target, path, level, componentPath) {
  if (level + 1 > target.length)
    return ast;
  let component = componentPath;
  target.forEach((item, index) => {
    item = utils.getFirst(item);
    if (index <= level) {
      component += `/${item}`;
    }
  });
  component = component + ".vue";
  let name = utils.getFirst(target[level]);
  let p = utils.strToVar(ast, path);
  let l = p.length;
  if (l) {
    let hasChild = false;
    p && p.forEach((item) => {
      if (item.key && item.key.name === "children") {
        hasChild = true;
      }
    });
    if (!hasChild && level != 0) {
      p.push({
        type: "ObjectProperty",
        method: false,
        shorthand: false,
        computed: false,
        key: {
          type: "Identifier",
          name: "children"
        },
        value: {
          type: "ArrayExpression",
          elements: []
        }
      });
      path = path + "[" + l + "]";
    }
  }
  let node = l ? p[l] : p;
  let len = level > 0 ? node.value.elements.length : p.length;
  node = level > 0 ? node.value.elements : p;
  node.push({
    type: "ObjectExpression",
    properties: [
      {
        type: "ObjectProperty",
        method: false,
        shorthand: false,
        computed: false,
        key: {
          type: "Identifier",
          name: "path"
        },
        value: {
          type: "StringLiteral",
          extra: {
            rawValue: level > 0 ? target[level] : "/" + target[level],
            raw: level > 0 ? `'${target[level]}'` : `'/${target[level]}'`
          },
          value: level > 0 ? target[level] : "/" + target[level]
        },
        kind: "init"
      },
      {
        type: "ObjectProperty",
        method: false,
        shorthand: false,
        computed: false,
        key: {
          type: "Identifier",
          name: "name"
        },
        value: {
          type: "StringLiteral",
          extra: {
            rawValue: name,
            raw: `'${name}'`
          },
          value: name
        },
        kind: "init"
      },
      {
        type: "ObjectProperty",
        method: false,
        shorthand: false,
        computed: false,
        key: {
          type: "Identifier",
          name: "component"
        },
        value: {
          type: "ArrowFunctionExpression",
          id: null,
          generator: false,
          async: false,
          params: [],
          body: {
            type: "CallExpression",
            callee: {
              type: "Import"
            },
            arguments: [
              {
                type: "StringLiteral",
                extra: {
                  rawValue: component,
                  raw: `'${component}'`
                },
                value: component
              }
            ]
          }
        }
      },
      level + 1 < target.length ? {
        type: "ObjectProperty",
        method: false,
        shorthand: false,
        computed: false,
        key: {
          type: "Identifier",
          name: "children"
        },
        value: {
          type: "ArrayExpression",
          elements: []
        }
      } : ""
    ]
  });
  path += level > 0 ? `['value']['elements'][${len}]['properties'][3]` : `[${len}]['properties'][3]`;
  return writeRouterAst(ast, target, path, level + 1, componentPath);
}
function createFile(target, pageDir) {
  let path$1 = pageDir;
  const ROOT = process.cwd();
  const templatePath = path.join(ROOT, "vrp.template.vue");
  let template = `<script setup>
import { reactive, ref } from 'vue';
<\/script>
<template>
    <div class="">
        <router-view></router-view>
    </div>
</template>
<style>
    
</style>`;
  if (fs__namespace.existsSync(templatePath)) {
    template = fs__namespace.readFileSync(templatePath, "utf-8");
  }
  target.forEach((item, index) => {
    item = utils.getFirst(item);
    if (index < target.length - 1) {
      path$1 += `/${item}`;
      if (!fs__namespace.existsSync(path$1)) {
        fs__namespace.mkdirSync(path$1);
      }
      if (!fs__namespace.existsSync(`${path$1}.vue`)) {
        ((path2) => {
          fs__namespace.writeFile(`${path2}.vue`, template, (err) => {
            if (!err) {
              console.log(`created a file: ${path2}.vue`);
            }
          });
        })(path$1);
      }
    } else {
      path$1 += `/${item}.vue`;
      if (!fs__namespace.existsSync(path$1)) {
        ((path2) => {
          fs__namespace.writeFile(path2, template, (err) => {
            if (!err) {
              console.log(`created a file: ${path2}`);
            }
          });
        })(path$1);
      }
    }
  });
}

exports.createFile = createFile;
exports.matchPath = matchPath;
exports.writeRouterAst = writeRouterAst;
